@@ -12,13 +12,14 @@
 #include <QQmlApplicationEngine>
 #include <QQmlContext>
 #include <QSessionManager>
+#include <QSurfaceFormat>
 #include <QWindow>
 
 #include <KAboutData>
 #include <KDBusService>
 #include <KDeclarative/KDeclarative>
 #include <KLocalizedString>
-#include <KQuickAddons/QtQuickSettings>
+#include <KWindowSystem>
 
 #include "Configuration.h"
 #include "ToolsModel.h"
@@ -48,9 +49,9 @@ class CommandLineArguments : public QObject
 public:
     CommandLineArguments(QCommandLineParser &parser)
         : QObject()
+        , m_pageId(parser.value(QStringLiteral("page-id")))
+        , m_pageName(parser.value(QStringLiteral("page-name")))
     {
-        m_pageId = parser.value(QStringLiteral("page-id"));
-        m_pageName = parser.value(QStringLiteral("page-name"));
     }
 
     QVariant aboutData() const
@@ -91,8 +92,14 @@ SessionManager::SessionManager(QObject *parent)
 
 int main(int argc, char **argv)
 {
+    auto format = QSurfaceFormat::defaultFormat();
+    format.setOption(QSurfaceFormat::ResetNotification);
+    QSurfaceFormat::setDefaultFormat(format);
+
     QApplication app(argc, argv);
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
     app.setAttribute(Qt::AA_UseHighDpiPixmaps, true);
+#endif
     app.setWindowIcon(QIcon::fromTheme(QStringLiteral("utilities-system-monitor")));
 
     oldCategoryFilter = QLoggingCategory::installFilter(filterConnectionSyntaxWarning);
@@ -140,8 +147,6 @@ int main(int argc, char **argv)
     });
     auto sessionManager = new SessionManager(&app);
 
-    KQuickAddons::QtQuickSettings::init();
-
     QQmlApplicationEngine engine;
     engine.rootContext()->setContextObject(new KLocalizedContext(&engine));
     engine.load(QUrl(QStringLiteral("qrc:/main.qml")));
@@ -149,8 +154,8 @@ int main(int argc, char **argv)
     QObject::connect(&service, &KDBusService::activateRequested, &engine, []() {
         if (!qApp->topLevelWindows().isEmpty()) {
             QWindow *win = qApp->topLevelWindows().first();
-            win->raise();
-            win->requestActivate();
+            KWindowSystem::updateStartupId(win);
+            KWindowSystem::activateWindow(win);
         }
     });
     // QDBusConnectionInterface::StartService is blocking so we do it manually
