@@ -60,7 +60,7 @@ QStringList ColumnSortModel::sortedColumns() const
 {
     QStringList result;
     auto source = sourceModel();
-    for (auto sourceRow : qAsConst(m_rowMapping)) {
+    for (auto sourceRow : std::as_const(m_rowMapping)) {
         result.append(source->data(source->index(sourceRow, 0), idRoleNumber()).toString());
     }
     return result;
@@ -77,7 +77,7 @@ void ColumnSortModel::setSortedColumns(const QStringList &newSortedColumns)
 
     beginResetModel();
     m_rowMapping.clear();
-    for (auto id : newSortedColumns) {
+    for (const auto &id : newSortedColumns) {
         auto row = sourceRowMapping.value(id, -1);
         if (row != -1) {
             m_rowMapping.append(row);
